@@ -255,7 +255,7 @@ class Utils(object):
 		try:
 			client = cls.docker_login(scan_info)
 			cls.docker_pull_image(client, cls.cloc_image)
-			command_line = "/scan --json --out /scan/sken-cloc.json  --exclude-dir node_modules,target,dist,build,node,.git,.hg --skip-archive '(zip|tar|jar|war(.(gz|Z|bz2|xz|7z))?)' --exclude-ext json,xml,svg,md"
+			command_line = "/scan --json --out /scan/sken-cloc.json  --exclude-dir node_modules,target,dist,build,node,.git,.hg,tests,tmp,temp,docs --skip-archive '(zip|tar|jar|war(.(gz|Z|bz2|xz|7z))?)' --exclude-ext json,xml,svg,md"
 			container = client.containers.run(cls.cloc_image, command_line, volumes={build_dir: {
 				'bind': '/scan', 'mode': 'rw'}}, detach=True, tty=False, stdout=True, stderr=True)
 			container.wait()
